@@ -22,7 +22,6 @@
 define('ZBX_PAGE_NO_HEADER', 1);
 define('ZBX_PAGE_NO_FOOTER', 1);
 
-$request = CHtml::encode(getRequest('request', ''));
 $message = CHtml::encode(getRequest('message', '')) ;
 // remove debug code for login form message, trimming not in regex to relay only on [ ] in debug message.
 $message = trim(preg_replace('/\[.*\]/', '', $message));
@@ -44,6 +43,8 @@ global $ZBX_SERVER_NAME;
 	(new CDiv([
 		(new CDiv())->addClass(ZBX_STYLE_SIGNIN_LOGO),
 		(new CForm())
+			->cleanItems()
+			->addItem(hasRequest('request') ? new CVar('request', getRequest('request')) : null)
 			->addItem(
 				(new CList())
 					->addItem([
